#ifndef POKEPLATINUM_UNK_02061804_H
#define POKEPLATINUM_UNK_02061804_H

#include "struct_decls/struct_02006C24_decl.h"
#include "struct_decls/struct_0201CD38_decl.h"
#include "struct_decls/struct_0203CDB0_decl.h"
#include "struct_decls/struct_02061830_decl.h"
#include "struct_decls/struct_020619DC_decl.h"
#include "struct_decls/struct_02061AB4_decl.h"
#include "struct_defs/struct_02061D3C.h"
#include "functypes/funcptr_020EDF0C.h"
#include "functypes/funcptr_020EDF0C_1.h"
#include "functypes/funcptr_020EDF0C_2.h"
#include "overlay005/struct_ov5_021ED0A4.h"
#include "overlay005/funcptr_ov5_021FB0F0.h"
#include "overlay005/funcptr_ov5_021FB0F0_1.h"
#include "overlay005/funcptr_ov5_021FB0F0_2.h"
#include "overlay005/funcptr_ov5_021FB0F0_3.h"
#include "overlay005/funcptr_ov5_021FB0F0_4.h"

#include <nitro/fx/fx.h>

UnkStruct_02061830 * sub_02061804(UnkStruct_0203CDB0 * param0, int param1, int param2);
void sub_02061830(UnkStruct_02061830 * param0);
void sub_0206184C(UnkStruct_02061830 * param0, int param1, int param2, int param3, const UnkStruct_020619DC * param4);
UnkStruct_02061AB4 * sub_02061918(const UnkStruct_02061830 * param0, const UnkStruct_020619DC * param1, int param2);
UnkStruct_02061AB4 * sub_020619DC(const UnkStruct_02061830 * param0, int param1, int param2, int param3, int param4, int param5, int param6);
UnkStruct_02061AB4 * sub_02061A74(const UnkStruct_02061830 * param0, int param1, int param2, int param3, const UnkStruct_020619DC * param4);
void sub_02061AB4(UnkStruct_02061AB4 * param0, int param1);
void sub_02061AD4(UnkStruct_02061AB4 * param0, int param1);
void sub_02061AF4(UnkStruct_02061AB4 * param0);
void sub_02061B28(UnkStruct_02061AB4 * param0);
void sub_02061B48(UnkStruct_02061AB4 * param0);
void sub_02061BBC(UnkStruct_02061830 * param0);
void sub_02061BF0(UnkStruct_02061830 * param0);
void sub_02061C48(UnkStruct_02061830 * param0);
void sub_02061CA8(UnkStruct_0203CDB0 * param0, const UnkStruct_02061830 * param1, UnkStruct_02061D3C * param2, int param3);
void sub_02061D04(const UnkStruct_02061830 * param0, UnkStruct_02061D3C * param1, int param2);
void sub_02062068(const UnkStruct_02061830 * param0, int param1, int param2, const UnkStruct_020619DC * param3);
UnkStruct_02061AB4 * sub_0206251C(const UnkStruct_02061830 * param0, int param1);
UnkStruct_02061AB4 * sub_02062570(const UnkStruct_02061830 * param0, int param1);
int sub_020625B0(const UnkStruct_02061830 * param0, UnkStruct_02061AB4 ** param1, int * param2, u32 param3);
int sub_020626B4(const UnkStruct_02061AB4 * param0);
int sub_02062758(const UnkStruct_02061AB4 * param0, int param1);
int sub_02062764(const UnkStruct_02061AB4 * param0, int param1, int param2);
int sub_020627B4(const UnkStruct_02061AB4 * param0, int param1, int param2, int param3);
void sub_02062820(UnkStruct_02061830 * param0, int param1);
int sub_02062824(const UnkStruct_02061830 * param0);
void sub_02062838(UnkStruct_02061830 * param0, u32 param1);
void sub_02062840(UnkStruct_02061830 * param0, u32 param1);
u32 sub_0206284C(const UnkStruct_02061830 * param0, u32 param1);
void sub_02062854(UnkStruct_02061830 * param0, int param1);
int sub_02062858(const UnkStruct_02061830 * param0);
UnkStruct_ov5_021ED0A4 * sub_0206285C(const UnkStruct_02061830 * param0);
void sub_02062860(UnkStruct_02061830 * param0, UnkStruct_02061AB4 * param1);
const UnkStruct_02061AB4 * sub_02062868(const UnkStruct_02061830 * param0);
UnkStruct_02061AB4 * sub_02062878(const UnkStruct_02061830 * param0);
void sub_02062880(const UnkStruct_02061AB4 ** param0);
void sub_0206288C(UnkStruct_02061830 * param0, UnkStruct_0203CDB0 * param1);
UnkStruct_0203CDB0 * sub_02062894(const UnkStruct_02061830 * param0);
void sub_0206289C(UnkStruct_02061830 * param0, NARC * param1);
NARC * sub_020628A0(const UnkStruct_02061830 * param0);
void sub_020628B4(UnkStruct_02061AB4 * param0, u32 param1);
u32 sub_020628B8(const UnkStruct_02061AB4 * param0);
void sub_020628BC(UnkStruct_02061AB4 * param0, u32 param1);
void sub_020628C4(UnkStruct_02061AB4 * param0, u32 param1);
u32 sub_020628D0(const UnkStruct_02061AB4 * param0, u32 param1);
u32 sub_020628D8(const UnkStruct_02061AB4 * param0, u32 param1);
void sub_020628E8(UnkStruct_02061AB4 * param0, u32 param1);
u32 sub_020628EC(const UnkStruct_02061AB4 * param0);
void sub_020628F0(UnkStruct_02061AB4 * param0, u32 param1);
void sub_020628F8(UnkStruct_02061AB4 * param0, u32 param1);
u32 sub_02062904(const UnkStruct_02061AB4 * param0, u32 param1);
void sub_0206290C(UnkStruct_02061AB4 * param0, u32 param1);
u32 sub_02062910(const UnkStruct_02061AB4 * param0);
void sub_02062914(UnkStruct_02061AB4 * param0, int param1);
int sub_02062918(const UnkStruct_02061AB4 * param0);
void sub_0206291C(UnkStruct_02061AB4 * param0, u32 param1);
u32 sub_02062920(const UnkStruct_02061AB4 * param0);
u32 sub_02062924(const UnkStruct_02061AB4 * param0);
void sub_02062944(UnkStruct_02061AB4 * param0, u32 param1);
u32 sub_02062948(const UnkStruct_02061AB4 * param0);
void sub_0206294C(UnkStruct_02061AB4 * param0, u32 param1);
u32 sub_02062950(const UnkStruct_02061AB4 * param0);
void sub_02062954(UnkStruct_02061AB4 * param0, u32 param1);
u32 sub_02062958(const UnkStruct_02061AB4 * param0);
void sub_0206295C(UnkStruct_02061AB4 * param0, u32 param1);
u32 sub_02062960(const UnkStruct_02061AB4 * param0);
void sub_02062964(UnkStruct_02061AB4 * param0, int param1);
u32 sub_02062968(const UnkStruct_02061AB4 * param0);
void sub_0206296C(UnkStruct_02061AB4 * param0, int param1);
void sub_02062974(UnkStruct_02061AB4 * param0, int param1);
int sub_0206298C(const UnkStruct_02061AB4 * param0);
int sub_02062990(const UnkStruct_02061AB4 * param0);
void sub_02062994(UnkStruct_02061AB4 * param0, int param1);
int sub_0206299C(const UnkStruct_02061AB4 * param0);
void sub_020629A0(UnkStruct_02061AB4 * param0, int param1);
void sub_020629B4(UnkStruct_02061AB4 * param0, int param1, int param2);
int sub_020629D8(const UnkStruct_02061AB4 * param0, int param1);
void sub_020629FC(UnkStruct_02061AB4 * param0, int param1);
int sub_02062A00(const UnkStruct_02061AB4 * param0);
void sub_02062A04(UnkStruct_02061AB4 * param0, int param1);
int sub_02062A08(const UnkStruct_02061AB4 * param0);
void sub_02062A0C(UnkStruct_02061AB4 * param0, u32 param1);
u32 sub_02062A14(const UnkStruct_02061AB4 * param0);
void sub_02062A1C(UnkStruct_02061AB4 * param0, UnkStruct_0201CD38 * param1);
UnkStruct_0201CD38 * sub_02062A24(const UnkStruct_02061AB4 * param0);
void sub_02062A2C(const UnkStruct_02061AB4 * param0);
void sub_02062A38(UnkStruct_02061AB4 * param0, const UnkStruct_02061830 * param1);
const UnkStruct_02061830 * sub_02062A40(const UnkStruct_02061AB4 * param0);
void * sub_02062A54(UnkStruct_02061AB4 * param0, int param1);
void * sub_02062A78(UnkStruct_02061AB4 * param0);
void * sub_02062A7C(UnkStruct_02061AB4 * param0, int param1);
void * sub_02062AA0(UnkStruct_02061AB4 * param0);
void * sub_02062AA4(UnkStruct_02061AB4 * param0, int param1);
void * sub_02062AC8(UnkStruct_02061AB4 * param0);
void * sub_02062ACC(UnkStruct_02061AB4 * param0, int param1);
void * sub_02062AF0(UnkStruct_02061AB4 * param0);
void sub_02062AF8(UnkStruct_02061AB4 * param0, UnkFuncPtr_020EDF0C param1);
void sub_02062B00(UnkStruct_02061AB4 * param0);
void sub_02062B0C(UnkStruct_02061AB4 * param0, UnkFuncPtr_020EDF0C_1 param1);
void sub_02062B14(UnkStruct_02061AB4 * param0);
void sub_02062B20(UnkStruct_02061AB4 * param0, UnkFuncPtr_020EDF0C_2 param1);
void sub_02062B28(UnkStruct_02061AB4 * param0);
void sub_02062B34(UnkStruct_02061AB4 * param0);
void sub_02062B4C(UnkStruct_02061AB4 * param0, UnkFuncPtr_ov5_021FB0F0 param1);
void sub_02062B54(UnkStruct_02061AB4 * param0);
void sub_02062B60(UnkStruct_02061AB4 * param0, UnkFuncPtr_ov5_021FB0F0_1 param1);
void sub_02062B68(UnkStruct_02061AB4 * param0);
void sub_02062B74(UnkStruct_02061AB4 * param0, UnkFuncPtr_ov5_021FB0F0_2 param1);
void sub_02062B7C(UnkStruct_02061AB4 * param0);
void sub_02062B88(UnkStruct_02061AB4 * param0, UnkFuncPtr_ov5_021FB0F0_3 param1);
void sub_02062B90(UnkStruct_02061AB4 * param0);
void sub_02062B9C(UnkStruct_02061AB4 * param0, UnkFuncPtr_ov5_021FB0F0_4 param1);
void sub_02062BA4(UnkStruct_02061AB4 * param0);
void sub_02062BB0(UnkStruct_02061AB4 * param0, int param1);
int sub_02062BB8(const UnkStruct_02061AB4 * param0);
void sub_02062BC0(UnkStruct_02061AB4 * param0, int param1);
void sub_02062BC8(UnkStruct_02061AB4 * param0);
int sub_02062BD8(const UnkStruct_02061AB4 * param0);
void sub_02062BE0(UnkStruct_02061AB4 * param0, u32 param1);
u32 sub_02062BE8(const UnkStruct_02061AB4 * param0);
void sub_02062BF0(UnkStruct_02061AB4 * param0, u32 param1);
u32 sub_02062BF8(const UnkStruct_02061AB4 * param0);
UnkStruct_0203CDB0 * sub_02062C00(const UnkStruct_02061AB4 * param0);
int sub_02062C0C(const UnkStruct_02061AB4 * param0);
int sub_02062C18(const UnkStruct_02061AB4 * param0);
void sub_02062C30(UnkStruct_02061830 * param0);
void sub_02062C3C(UnkStruct_02061830 * param0);
void sub_02062C48(UnkStruct_02061830 * param0);
void sub_02062C78(UnkStruct_02061830 * param0);
int sub_02062CA8(const UnkStruct_02061830 * param0);
u32 sub_02062CBC(const UnkStruct_02061AB4 * param0, u32 param1);
void sub_02062CCC(UnkStruct_02061830 * param0, int param1);
int sub_02062CE4(const UnkStruct_02061830 * param0);
int sub_02062CF8(const UnkStruct_02061AB4 * param0);
void sub_02062D04(UnkStruct_02061AB4 * param0);
void sub_02062D10(UnkStruct_02061AB4 * param0);
int sub_02062D1C(const UnkStruct_02061AB4 * param0);
void sub_02062D28(UnkStruct_02061AB4 * param0);
void sub_02062D34(UnkStruct_02061AB4 * param0);
void sub_02062D40(UnkStruct_02061AB4 * param0);
int sub_02062D4C(const UnkStruct_02061AB4 * param0);
int sub_02062D58(const UnkStruct_02061AB4 * param0);
void sub_02062D64(UnkStruct_02061AB4 * param0, int param1);
void sub_02062D80(UnkStruct_02061AB4 * param0, int param1);
int sub_02062D9C(UnkStruct_02061AB4 * param0);
void sub_02062DB4(UnkStruct_02061AB4 * param0, int param1);
void sub_02062DD0(UnkStruct_02061AB4 * param0);
void sub_02062DDC(UnkStruct_02061AB4 * param0);
int sub_02062DE8(const UnkStruct_02061AB4 * param0);
int sub_02062DFC(const UnkStruct_02061AB4 * param0);
void sub_02062E28(UnkStruct_02061AB4 * param0, int param1);
int sub_02062E44(const UnkStruct_02061AB4 * param0);
void sub_02062E5C(UnkStruct_02061AB4 * param0, int param1);
void sub_02062E78(UnkStruct_02061AB4 * param0, int param1);
int sub_02062E94(const UnkStruct_02061AB4 * param0);
void sub_02062EAC(UnkStruct_02061AB4 * param0, int param1);
int sub_02062EC8(const UnkStruct_02061AB4 * param0);
void sub_02062EE0(UnkStruct_02061AB4 * param0, int param1);
int sub_02062EFC(const UnkStruct_02061AB4 * param0);
void sub_02062F14(UnkStruct_02061AB4 * param0, int param1);
int sub_02062F30(const UnkStruct_02061AB4 * param0);
void sub_02062F48(UnkStruct_02061AB4 * param0, int param1);
int sub_02062F64(const UnkStruct_02061AB4 * param0);
int sub_02062F7C(const UnkStruct_02061AB4 * param0);
void sub_02062F90(UnkStruct_02061AB4 * param0, int param1);
int sub_02062FAC(const UnkStruct_02061AB4 * param0);
void sub_02062FC4(UnkStruct_02061AB4 * param0, int param1);
int sub_02062FDC(const UnkStruct_02061AB4 * param0);
int sub_02062FF0(const UnkStruct_02061AB4 * param0);
void sub_02062FF4(UnkStruct_02061AB4 * param0, int param1);
int sub_02062FF8(const UnkStruct_02061AB4 * param0);
void sub_02062FFC(UnkStruct_02061AB4 * param0, int param1);
int sub_02063000(const UnkStruct_02061AB4 * param0);
void sub_02063004(UnkStruct_02061AB4 * param0, int param1);
int sub_02063008(const UnkStruct_02061AB4 * param0);
void sub_0206300C(UnkStruct_02061AB4 * param0, int param1);
int sub_02063010(const UnkStruct_02061AB4 * param0);
void sub_02063014(UnkStruct_02061AB4 * param0, int param1);
int sub_02063018(const UnkStruct_02061AB4 * param0);
void sub_0206301C(UnkStruct_02061AB4 * param0, int param1);
int sub_02063020(const UnkStruct_02061AB4 * param0);
void sub_02063024(UnkStruct_02061AB4 * param0, int param1);
void sub_02063028(UnkStruct_02061AB4 * param0, int param1);
int sub_02063030(const UnkStruct_02061AB4 * param0);
void sub_02063034(UnkStruct_02061AB4 * param0, int param1);
void sub_02063038(UnkStruct_02061AB4 * param0, int param1);
int sub_02063040(const UnkStruct_02061AB4 * param0);
void sub_02063044(UnkStruct_02061AB4 * param0, int param1);
void sub_02063048(UnkStruct_02061AB4 * param0, int param1);
void sub_02063050(const UnkStruct_02061AB4 * param0, VecFx32 * param1);
void sub_02063060(UnkStruct_02061AB4 * param0, const VecFx32 * param1);
const VecFx32 * sub_02063070(const UnkStruct_02061AB4 * param0);
fx32 sub_02063074(const UnkStruct_02061AB4 * param0);
void sub_02063078(const UnkStruct_02061AB4 * param0, VecFx32 * param1);
void sub_02063088(UnkStruct_02061AB4 * param0, const VecFx32 * param1);
VecFx32 * sub_02063098(UnkStruct_02061AB4 * param0);
void sub_0206309C(const UnkStruct_02061AB4 * param0, VecFx32 * param1);
void sub_020630AC(UnkStruct_02061AB4 * param0, const VecFx32 * param1);
void sub_020630BC(const UnkStruct_02061AB4 * param0, VecFx32 * param1);
void sub_020630CC(UnkStruct_02061AB4 * param0, const VecFx32 * param1);
int sub_020630DC(const UnkStruct_02061AB4 * param0);
void sub_020630F0(UnkStruct_020619DC * param0, int param1);
int sub_020630F4(const UnkStruct_020619DC * param0);
void sub_020630F8(UnkStruct_020619DC * param0, int param1);
int sub_020630FC(const UnkStruct_020619DC * param0);
void sub_02063100(UnkStruct_020619DC * param0, int param1);
int sub_02063104(const UnkStruct_020619DC * param0);
void sub_02063108(UnkStruct_020619DC * param0, int param1);
int sub_0206310C(const UnkStruct_020619DC * param0);
void sub_02063110(UnkStruct_020619DC * param0, int param1);
int sub_02063114(const UnkStruct_020619DC * param0);
void sub_02063118(UnkStruct_020619DC * param0, int param1);
int sub_0206311C(const UnkStruct_020619DC * param0);
void sub_02063120(UnkStruct_020619DC * param0, int param1);
int sub_02063124(const UnkStruct_020619DC * param0);
void sub_0206312C(UnkStruct_020619DC * param0, int param1, int param2);
int sub_02063150(const UnkStruct_020619DC * param0, int param1);
void sub_02063174(UnkStruct_020619DC * param0, int param1);
int sub_02063178(const UnkStruct_020619DC * param0);
void sub_02063180(UnkStruct_020619DC * param0, int param1);
int sub_02063184(const UnkStruct_020619DC * param0);
void sub_0206318C(UnkStruct_020619DC * param0, int param1);
int sub_02063190(const UnkStruct_020619DC * param0);
void sub_02063194(UnkStruct_020619DC * param0, int param1);
int sub_02063198(const UnkStruct_020619DC * param0);
void sub_0206319C(UnkStruct_020619DC * param0, int param1);
int sub_020631A0(const UnkStruct_020619DC * param0);
UnkStruct_02061AB4 * sub_0206326C(const UnkStruct_02061830 * param0, int param1, int param2, int param3);
void sub_020632D4(UnkStruct_02061AB4 * param0, const VecFx32 * param1, int param2);
void sub_02063340(UnkStruct_02061AB4 * param0, int param1, int param2, int param3, int param4);
void sub_020633A8(UnkStruct_02061AB4 * param0, u32 param1);
void sub_020633C8(UnkStruct_02061AB4 * param0, int param1);
void sub_020633E0(UnkStruct_02061AB4 * param0);
void sub_020633E4(UnkStruct_02061AB4 * param0);
void sub_020633E8(UnkStruct_02061AB4 * param0);
void sub_020633EC(UnkStruct_02061AB4 * param0);
void sub_020633F0(UnkStruct_02061AB4 * param0);
void sub_020633F4(UnkStruct_02061AB4 * param0);
void sub_020633F8(UnkStruct_02061AB4 * param0);
void sub_020633FC(UnkStruct_02061AB4 * param0);

#endif // POKEPLATINUM_UNK_02061804_H
